# Stairval

Validation framework for hierarchical data structures

## Setup

The package is available from PyPi:

```shell
python3 -m pip install stairval
```

## Learn more

Find more info in our detailed documentation:

- [Stable documentation](https://ielis.github.io/stairval/stable) (last release on `master` branch)
- [Latest documentation](https://ielis.github.io/stairval/latest) (bleeding edge, latest commit on `develop` branch)
